# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v2/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.exchange.v2 import exchange_pb2 as injective_dot_exchange_dot_v2_dot_exchange__pb2
from pyinjective.proto.injective.exchange.v2 import order_pb2 as injective_dot_exchange_dot_v2_dot_order__pb2
from pyinjective.proto.injective.exchange.v2 import market_pb2 as injective_dot_exchange_dot_v2_dot_market__pb2
from pyinjective.proto.injective.exchange.v2 import proposal_pb2 as injective_dot_exchange_dot_v2_dot_proposal__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/exchange/v2/tx.proto\x12\x15injective.exchange.v2\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a.cosmos/distribution/v1beta1/distribution.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a$injective/exchange/v2/exchange.proto\x1a!injective/exchange/v2/order.proto\x1a\"injective/exchange/v2/market.proto\x1a$injective/exchange/v2/proposal.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x11\x61mino/amino.proto\"\xa3\x03\n\x13MsgUpdateSpotMarket\x12\x14\n\x05\x61\x64min\x18\x01 \x01(\tR\x05\x61\x64min\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1d\n\nnew_ticker\x18\x03 \x01(\tR\tnewTicker\x12Y\n\x17new_min_price_tick_size\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13newMinPriceTickSize\x12_\n\x1anew_min_quantity_tick_size\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x16newMinQuantityTickSize\x12M\n\x10new_min_notional\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0enewMinNotional:/\xe8\xa0\x1f\x00\x82\xe7\xb0*\x05\x61\x64min\x8a\xe7\xb0*\x1c\x65xchange/MsgUpdateSpotMarket\"\x1d\n\x1bMsgUpdateSpotMarketResponse\"\xd3\x05\n\x19MsgUpdateDerivativeMarket\x12\x14\n\x05\x61\x64min\x18\x01 \x01(\tR\x05\x61\x64min\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1d\n\nnew_ticker\x18\x03 \x01(\tR\tnewTicker\x12Y\n\x17new_min_price_tick_size\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13newMinPriceTickSize\x12_\n\x1anew_min_quantity_tick_size\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x16newMinQuantityTickSize\x12M\n\x10new_min_notional\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0enewMinNotional\x12\\\n\x18new_initial_margin_ratio\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x15newInitialMarginRatio\x12\x64\n\x1cnew_maintenance_margin_ratio\x18\x08 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x19newMaintenanceMarginRatio\x12Z\n\x17new_reduce_margin_ratio\x18\t \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x14newReduceMarginRatio:9\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x05\x61\x64min\x8a\xe7\xb0*\"exchange/MsgUpdateDerivativeMarket\"#\n!MsgUpdateDerivativeMarketResponse\"\xb3\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12;\n\x06params\x18\x02 \x01(\x0b\x32\x1d.injective.exchange.v2.ParamsB\x04\xc8\xde\x1f\x00R\x06params:+\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x18\x65xchange/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xaf\x01\n\nMsgDeposit\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount:+\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x13\x65xchange/MsgDeposit\"\x14\n\x12MsgDepositResponse\"\xb1\x01\n\x0bMsgWithdraw\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount:,\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x14\x65xchange/MsgWithdraw\"\x15\n\x13MsgWithdrawResponse\"\xa9\x01\n\x17MsgCreateSpotLimitOrder\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12<\n\x05order\x18\x02 \x01(\x0b\x32 .injective.exchange.v2.SpotOrderB\x04\xc8\xde\x1f\x00R\x05order:8\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0* exchange/MsgCreateSpotLimitOrder\"\\\n\x1fMsgCreateSpotLimitOrderResponse\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x02 \x01(\tR\x03\x63id:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb7\x01\n\x1dMsgBatchCreateSpotLimitOrders\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12>\n\x06orders\x18\x02 \x03(\x0b\x32 .injective.exchange.v2.SpotOrderB\x04\xc8\xde\x1f\x00R\x06orders:>\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*&exchange/MsgBatchCreateSpotLimitOrders\"\xb2\x01\n%MsgBatchCreateSpotLimitOrdersResponse\x12!\n\x0corder_hashes\x18\x01 \x03(\tR\x0borderHashes\x12.\n\x13\x63reated_orders_cids\x18\x02 \x03(\tR\x11\x63reatedOrdersCids\x12,\n\x12\x66\x61iled_orders_cids\x18\x03 \x03(\tR\x10\x66\x61iledOrdersCids:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x8b\x04\n\x1aMsgInstantSpotMarketLaunch\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x16\n\x06ticker\x18\x02 \x01(\tR\x06ticker\x12\x1d\n\nbase_denom\x18\x03 \x01(\tR\tbaseDenom\x12\x1f\n\x0bquote_denom\x18\x04 \x01(\tR\nquoteDenom\x12R\n\x13min_price_tick_size\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x10minPriceTickSize\x12X\n\x16min_quantity_tick_size\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13minQuantityTickSize\x12\x46\n\x0cmin_notional\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bminNotional\x12#\n\rbase_decimals\x18\x08 \x01(\rR\x0c\x62\x61seDecimals\x12%\n\x0equote_decimals\x18\t \x01(\rR\rquoteDecimals:;\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*#exchange/MsgInstantSpotMarketLaunch\"$\n\"MsgInstantSpotMarketLaunchResponse\"\x86\x08\n\x1fMsgInstantPerpetualMarketLaunch\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x16\n\x06ticker\x18\x02 \x01(\tR\x06ticker\x12\x1f\n\x0bquote_denom\x18\x03 \x01(\tR\nquoteDenom\x12\x1f\n\x0boracle_base\x18\x04 \x01(\tR\noracleBase\x12!\n\x0coracle_quote\x18\x05 \x01(\tR\x0boracleQuote\x12.\n\x13oracle_scale_factor\x18\x06 \x01(\rR\x11oracleScaleFactor\x12\x45\n\x0boracle_type\x18\x07 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\x12I\n\x0emaker_fee_rate\x18\x08 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0cmakerFeeRate\x12I\n\x0etaker_fee_rate\x18\t \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ctakerFeeRate\x12U\n\x14initial_margin_ratio\x18\n \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x12initialMarginRatio\x12]\n\x18maintenance_margin_ratio\x18\x0b \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x16maintenanceMarginRatio\x12R\n\x13min_price_tick_size\x18\x0c \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x10minPriceTickSize\x12X\n\x16min_quantity_tick_size\x18\r \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13minQuantityTickSize\x12\x46\n\x0cmin_notional\x18\x0e \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bminNotional\x12S\n\x13reduce_margin_ratio\x18\x0f \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x11reduceMarginRatio:@\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*(exchange/MsgInstantPerpetualMarketLaunch\")\n\'MsgInstantPerpetualMarketLaunchResponse\"\x89\x07\n#MsgInstantBinaryOptionsMarketLaunch\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x16\n\x06ticker\x18\x02 \x01(\tR\x06ticker\x12#\n\roracle_symbol\x18\x03 \x01(\tR\x0coracleSymbol\x12\'\n\x0foracle_provider\x18\x04 \x01(\tR\x0eoracleProvider\x12\x45\n\x0boracle_type\x18\x05 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\x12.\n\x13oracle_scale_factor\x18\x06 \x01(\rR\x11oracleScaleFactor\x12I\n\x0emaker_fee_rate\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0cmakerFeeRate\x12I\n\x0etaker_fee_rate\x18\x08 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ctakerFeeRate\x12\x31\n\x14\x65xpiration_timestamp\x18\t \x01(\x03R\x13\x65xpirationTimestamp\x12\x31\n\x14settlement_timestamp\x18\n \x01(\x03R\x13settlementTimestamp\x12\x14\n\x05\x61\x64min\x18\x0b \x01(\tR\x05\x61\x64min\x12\x1f\n\x0bquote_denom\x18\x0c \x01(\tR\nquoteDenom\x12R\n\x13min_price_tick_size\x18\r \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x10minPriceTickSize\x12X\n\x16min_quantity_tick_size\x18\x0e \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13minQuantityTickSize\x12\x46\n\x0cmin_notional\x18\x0f \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bminNotional:D\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*,exchange/MsgInstantBinaryOptionsMarketLaunch\"-\n+MsgInstantBinaryOptionsMarketLaunchResponse\"\xa6\x08\n#MsgInstantExpiryFuturesMarketLaunch\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x16\n\x06ticker\x18\x02 \x01(\tR\x06ticker\x12\x1f\n\x0bquote_denom\x18\x03 \x01(\tR\nquoteDenom\x12\x1f\n\x0boracle_base\x18\x04 \x01(\tR\noracleBase\x12!\n\x0coracle_quote\x18\x05 \x01(\tR\x0boracleQuote\x12\x45\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\x12.\n\x13oracle_scale_factor\x18\x07 \x01(\rR\x11oracleScaleFactor\x12\x16\n\x06\x65xpiry\x18\x08 \x01(\x03R\x06\x65xpiry\x12I\n\x0emaker_fee_rate\x18\t \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0cmakerFeeRate\x12I\n\x0etaker_fee_rate\x18\n \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ctakerFeeRate\x12U\n\x14initial_margin_ratio\x18\x0b \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x12initialMarginRatio\x12]\n\x18maintenance_margin_ratio\x18\x0c \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x16maintenanceMarginRatio\x12R\n\x13min_price_tick_size\x18\r \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x10minPriceTickSize\x12X\n\x16min_quantity_tick_size\x18\x0e \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13minQuantityTickSize\x12\x46\n\x0cmin_notional\x18\x0f \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bminNotional\x12S\n\x13reduce_margin_ratio\x18\x10 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x11reduceMarginRatio:D\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*,exchange/MsgInstantExpiryFuturesMarketLaunch\"-\n+MsgInstantExpiryFuturesMarketLaunchResponse\"\xab\x01\n\x18MsgCreateSpotMarketOrder\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12<\n\x05order\x18\x02 \x01(\x0b\x32 .injective.exchange.v2.SpotOrderB\x04\xc8\xde\x1f\x00R\x05order:9\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*!exchange/MsgCreateSpotMarketOrder\"\xac\x01\n MsgCreateSpotMarketOrderResponse\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12M\n\x07results\x18\x02 \x01(\x0b\x32-.injective.exchange.v2.SpotMarketOrderResultsB\x04\xc8\xde\x1f\x01R\x07results\x12\x10\n\x03\x63id\x18\x03 \x01(\tR\x03\x63id:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xd5\x01\n\x16SpotMarketOrderResults\x12?\n\x08quantity\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12\x39\n\x05price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12\x35\n\x03\x66\x65\x65\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x03\x66\x65\x65:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb7\x01\n\x1dMsgCreateDerivativeLimitOrder\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x42\n\x05order\x18\x02 \x01(\x0b\x32&.injective.exchange.v2.DerivativeOrderB\x04\xc8\xde\x1f\x00R\x05order::\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*&exchange/MsgCreateDerivativeLimitOrder\"b\n%MsgCreateDerivativeLimitOrderResponse\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x02 \x01(\tR\x03\x63id:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xbd\x01\n MsgCreateBinaryOptionsLimitOrder\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x42\n\x05order\x18\x02 \x01(\x0b\x32&.injective.exchange.v2.DerivativeOrderB\x04\xc8\xde\x1f\x00R\x05order:=\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*)exchange/MsgCreateBinaryOptionsLimitOrder\"e\n(MsgCreateBinaryOptionsLimitOrderResponse\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x02 \x01(\tR\x03\x63id:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xc5\x01\n#MsgBatchCreateDerivativeLimitOrders\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x44\n\x06orders\x18\x02 \x03(\x0b\x32&.injective.exchange.v2.DerivativeOrderB\x04\xc8\xde\x1f\x00R\x06orders:@\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*,exchange/MsgBatchCreateDerivativeLimitOrders\"\xb8\x01\n+MsgBatchCreateDerivativeLimitOrdersResponse\x12!\n\x0corder_hashes\x18\x01 \x03(\tR\x0borderHashes\x12.\n\x13\x63reated_orders_cids\x18\x02 \x03(\tR\x11\x63reatedOrdersCids\x12,\n\x12\x66\x61iled_orders_cids\x18\x03 \x03(\tR\x10\x66\x61iledOrdersCids:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xd0\x01\n\x12MsgCancelSpotOrder\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x1d\n\norder_hash\x18\x04 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x05 \x01(\tR\x03\x63id:/\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1b\x65xchange/MsgCancelSpotOrder\"\x1c\n\x1aMsgCancelSpotOrderResponse\"\xa5\x01\n\x18MsgBatchCancelSpotOrders\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12:\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32 .injective.exchange.v2.OrderDataB\x04\xc8\xde\x1f\x00R\x04\x64\x61ta:5\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*!exchange/MsgBatchCancelSpotOrders\"F\n MsgBatchCancelSpotOrdersResponse\x12\x18\n\x07success\x18\x01 \x03(\x08R\x07success:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb7\x01\n!MsgBatchCancelBinaryOptionsOrders\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12:\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32 .injective.exchange.v2.OrderDataB\x04\xc8\xde\x1f\x00R\x04\x64\x61ta:>\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0**exchange/MsgBatchCancelBinaryOptionsOrders\"O\n)MsgBatchCancelBinaryOptionsOrdersResponse\x12\x18\n\x07success\x18\x01 \x03(\x08R\x07success:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xd4\x07\n\x14MsgBatchUpdateOrders\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12?\n\x1dspot_market_ids_to_cancel_all\x18\x03 \x03(\tR\x18spotMarketIdsToCancelAll\x12K\n#derivative_market_ids_to_cancel_all\x18\x04 \x03(\tR\x1e\x64\x65rivativeMarketIdsToCancelAll\x12Y\n\x15spot_orders_to_cancel\x18\x05 \x03(\x0b\x32 .injective.exchange.v2.OrderDataB\x04\xc8\xde\x1f\x01R\x12spotOrdersToCancel\x12\x65\n\x1b\x64\x65rivative_orders_to_cancel\x18\x06 \x03(\x0b\x32 .injective.exchange.v2.OrderDataB\x04\xc8\xde\x1f\x01R\x18\x64\x65rivativeOrdersToCancel\x12Y\n\x15spot_orders_to_create\x18\x07 \x03(\x0b\x32 .injective.exchange.v2.SpotOrderB\x04\xc8\xde\x1f\x01R\x12spotOrdersToCreate\x12k\n\x1b\x64\x65rivative_orders_to_create\x18\x08 \x03(\x0b\x32&.injective.exchange.v2.DerivativeOrderB\x04\xc8\xde\x1f\x01R\x18\x64\x65rivativeOrdersToCreate\x12l\n\x1f\x62inary_options_orders_to_cancel\x18\t \x03(\x0b\x32 .injective.exchange.v2.OrderDataB\x04\xc8\xde\x1f\x01R\x1b\x62inaryOptionsOrdersToCancel\x12R\n\'binary_options_market_ids_to_cancel_all\x18\n \x03(\tR!binaryOptionsMarketIdsToCancelAll\x12r\n\x1f\x62inary_options_orders_to_create\x18\x0b \x03(\x0b\x32&.injective.exchange.v2.DerivativeOrderB\x04\xc8\xde\x1f\x01R\x1b\x62inaryOptionsOrdersToCreate:1\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1d\x65xchange/MsgBatchUpdateOrders\"\x88\x06\n\x1cMsgBatchUpdateOrdersResponse\x12.\n\x13spot_cancel_success\x18\x01 \x03(\x08R\x11spotCancelSuccess\x12:\n\x19\x64\x65rivative_cancel_success\x18\x02 \x03(\x08R\x17\x64\x65rivativeCancelSuccess\x12*\n\x11spot_order_hashes\x18\x03 \x03(\tR\x0fspotOrderHashes\x12\x36\n\x17\x64\x65rivative_order_hashes\x18\x04 \x03(\tR\x15\x64\x65rivativeOrderHashes\x12\x41\n\x1d\x62inary_options_cancel_success\x18\x05 \x03(\x08R\x1a\x62inaryOptionsCancelSuccess\x12=\n\x1b\x62inary_options_order_hashes\x18\x06 \x03(\tR\x18\x62inaryOptionsOrderHashes\x12\x37\n\x18\x63reated_spot_orders_cids\x18\x07 \x03(\tR\x15\x63reatedSpotOrdersCids\x12\x35\n\x17\x66\x61iled_spot_orders_cids\x18\x08 \x03(\tR\x14\x66\x61iledSpotOrdersCids\x12\x43\n\x1e\x63reated_derivative_orders_cids\x18\t \x03(\tR\x1b\x63reatedDerivativeOrdersCids\x12\x41\n\x1d\x66\x61iled_derivative_orders_cids\x18\n \x03(\tR\x1a\x66\x61iledDerivativeOrdersCids\x12J\n\"created_binary_options_orders_cids\x18\x0b \x03(\tR\x1e\x63reatedBinaryOptionsOrdersCids\x12H\n!failed_binary_options_orders_cids\x18\x0c \x03(\tR\x1d\x66\x61iledBinaryOptionsOrdersCids:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb9\x01\n\x1eMsgCreateDerivativeMarketOrder\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x42\n\x05order\x18\x02 \x01(\x0b\x32&.injective.exchange.v2.DerivativeOrderB\x04\xc8\xde\x1f\x00R\x05order:;\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\'exchange/MsgCreateDerivativeMarketOrder\"\xb8\x01\n&MsgCreateDerivativeMarketOrderResponse\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12S\n\x07results\x18\x02 \x01(\x0b\x32\x33.injective.exchange.v2.DerivativeMarketOrderResultsB\x04\xc8\xde\x1f\x01R\x07results\x12\x10\n\x03\x63id\x18\x03 \x01(\tR\x03\x63id:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xeb\x02\n\x1c\x44\x65rivativeMarketOrderResults\x12?\n\x08quantity\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12\x39\n\x05price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12\x35\n\x03\x66\x65\x65\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x03\x66\x65\x65\x12Q\n\x0eposition_delta\x18\x04 \x01(\x0b\x32$.injective.exchange.v2.PositionDeltaB\x04\xc8\xde\x1f\x00R\rpositionDelta\x12;\n\x06payout\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06payout:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xbf\x01\n!MsgCreateBinaryOptionsMarketOrder\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x42\n\x05order\x18\x02 \x01(\x0b\x32&.injective.exchange.v2.DerivativeOrderB\x04\xc8\xde\x1f\x00R\x05order:>\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0**exchange/MsgCreateBinaryOptionsMarketOrder\"\xbb\x01\n)MsgCreateBinaryOptionsMarketOrderResponse\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12S\n\x07results\x18\x02 \x01(\x0b\x32\x33.injective.exchange.v2.DerivativeMarketOrderResultsB\x04\xc8\xde\x1f\x01R\x07results\x12\x10\n\x03\x63id\x18\x03 \x01(\tR\x03\x63id:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xfb\x01\n\x18MsgCancelDerivativeOrder\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x1d\n\norder_hash\x18\x04 \x01(\tR\torderHash\x12\x1d\n\norder_mask\x18\x05 \x01(\x05R\torderMask\x12\x10\n\x03\x63id\x18\x06 \x01(\tR\x03\x63id:5\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*!exchange/MsgCancelDerivativeOrder\"\"\n MsgCancelDerivativeOrderResponse\"\x81\x02\n\x1bMsgCancelBinaryOptionsOrder\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x1d\n\norder_hash\x18\x04 \x01(\tR\torderHash\x12\x1d\n\norder_mask\x18\x05 \x01(\x05R\torderMask\x12\x10\n\x03\x63id\x18\x06 \x01(\tR\x03\x63id:8\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*$exchange/MsgCancelBinaryOptionsOrder\"%\n#MsgCancelBinaryOptionsOrderResponse\"\x9d\x01\n\tOrderData\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x1d\n\norder_hash\x18\x03 \x01(\tR\torderHash\x12\x1d\n\norder_mask\x18\x04 \x01(\x05R\torderMask\x12\x10\n\x03\x63id\x18\x05 \x01(\tR\x03\x63id\"\xb1\x01\n\x1eMsgBatchCancelDerivativeOrders\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12:\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32 .injective.exchange.v2.OrderDataB\x04\xc8\xde\x1f\x00R\x04\x64\x61ta:;\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\'exchange/MsgBatchCancelDerivativeOrders\"L\n&MsgBatchCancelDerivativeOrdersResponse\x12\x18\n\x07success\x18\x01 \x03(\x08R\x07success:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x86\x02\n\x15MsgSubaccountTransfer\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x30\n\x14source_subaccount_id\x18\x02 \x01(\tR\x12sourceSubaccountId\x12:\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\tR\x17\x64\x65stinationSubaccountId\x12\x37\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount:.\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1e\x65xchange/MsgSubaccountTransfer\"\x1f\n\x1dMsgSubaccountTransferResponse\"\x82\x02\n\x13MsgExternalTransfer\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x30\n\x14source_subaccount_id\x18\x02 \x01(\tR\x12sourceSubaccountId\x12:\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\tR\x17\x64\x65stinationSubaccountId\x12\x37\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount:,\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1c\x65xchange/MsgExternalTransfer\"\x1d\n\x1bMsgExternalTransferResponse\"\xe3\x01\n\x14MsgLiquidatePosition\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12\x42\n\x05order\x18\x04 \x01(\x0b\x32&.injective.exchange.v2.DerivativeOrderB\x04\xc8\xde\x1f\x01R\x05order:-\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1d\x65xchange/MsgLiquidatePosition\"\x1e\n\x1cMsgLiquidatePositionResponse\"\xa7\x01\n\x18MsgEmergencySettleMarket\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId:1\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*!exchange/MsgEmergencySettleMarket\"\"\n MsgEmergencySettleMarketResponse\"\xaf\x02\n\x19MsgIncreasePositionMargin\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x30\n\x14source_subaccount_id\x18\x02 \x01(\tR\x12sourceSubaccountId\x12:\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\tR\x17\x64\x65stinationSubaccountId\x12\x1b\n\tmarket_id\x18\x04 \x01(\tR\x08marketId\x12;\n\x06\x61mount\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06\x61mount:2\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\"exchange/MsgIncreasePositionMargin\"#\n!MsgIncreasePositionMarginResponse\"\xaf\x02\n\x19MsgDecreasePositionMargin\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x30\n\x14source_subaccount_id\x18\x02 \x01(\tR\x12sourceSubaccountId\x12:\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\tR\x17\x64\x65stinationSubaccountId\x12\x1b\n\tmarket_id\x18\x04 \x01(\tR\x08marketId\x12;\n\x06\x61mount\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06\x61mount:2\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\"exchange/MsgDecreasePositionMargin\"#\n!MsgDecreasePositionMarginResponse\"\xca\x01\n\x1cMsgPrivilegedExecuteContract\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x14\n\x05\x66unds\x18\x02 \x01(\tR\x05\x66unds\x12)\n\x10\x63ontract_address\x18\x03 \x01(\tR\x0f\x63ontractAddress\x12\x12\n\x04\x64\x61ta\x18\x04 \x01(\tR\x04\x64\x61ta:=\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*%exchange/MsgPrivilegedExecuteContract\"\xa7\x01\n$MsgPrivilegedExecuteContractResponse\x12j\n\nfunds_diff\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\tfundsDiff:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"]\n\x10MsgRewardsOptOut\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender:1\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x19\x65xchange/MsgRewardsOptOut\"\x1a\n\x18MsgRewardsOptOutResponse\"\xaf\x01\n\x15MsgReclaimLockedFunds\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x30\n\x13lockedAccountPubKey\x18\x02 \x01(\x0cR\x13lockedAccountPubKey\x12\x1c\n\tsignature\x18\x03 \x01(\x0cR\tsignature:.\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1e\x65xchange/MsgReclaimLockedFunds\"\x1f\n\x1dMsgReclaimLockedFundsResponse\"\x80\x01\n\x0bMsgSignData\x12S\n\x06Signer\x18\x01 \x01(\x0c\x42;\xea\xde\x1f\x06signer\xfa\xde\x1f-github.com/cosmos/cosmos-sdk/types.AccAddressR\x06Signer\x12\x1c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x42\x08\xea\xde\x1f\x04\x64\x61taR\x04\x44\x61ta\"s\n\nMsgSignDoc\x12%\n\tsign_type\x18\x01 \x01(\tB\x08\xea\xde\x1f\x04typeR\x08signType\x12>\n\x05value\x18\x02 \x01(\x0b\x32\".injective.exchange.v2.MsgSignDataB\x04\xc8\xde\x1f\x00R\x05value\"\x87\x03\n!MsgAdminUpdateBinaryOptionsMarket\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12N\n\x10settlement_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0fsettlementPrice\x12\x31\n\x14\x65xpiration_timestamp\x18\x04 \x01(\x03R\x13\x65xpirationTimestamp\x12\x31\n\x14settlement_timestamp\x18\x05 \x01(\x03R\x13settlementTimestamp\x12;\n\x06status\x18\x06 \x01(\x0e\x32#.injective.exchange.v2.MarketStatusR\x06status::\x82\xe7\xb0*\x06sender\x8a\xe7\xb0**exchange/MsgAdminUpdateBinaryOptionsMarket\"+\n)MsgAdminUpdateBinaryOptionsMarketResponse\"\xa6\x01\n\x17MsgAuthorizeStakeGrants\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x41\n\x06grants\x18\x02 \x03(\x0b\x32).injective.exchange.v2.GrantAuthorizationR\x06grants:0\x82\xe7\xb0*\x06sender\x8a\xe7\xb0* exchange/MsgAuthorizeStakeGrants\"!\n\x1fMsgAuthorizeStakeGrantsResponse\"y\n\x15MsgActivateStakeGrant\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x18\n\x07granter\x18\x02 \x01(\tR\x07granter:.\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1e\x65xchange/MsgActivateStakeGrant\"\x1f\n\x1dMsgActivateStakeGrantResponse\"\xcb\x01\n\x1cMsgBatchExchangeModification\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12T\n\x08proposal\x18\x02 \x01(\x0b\x32\x38.injective.exchange.v2.BatchExchangeModificationProposalR\x08proposal:=\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*%exchange/MsgBatchExchangeModification\"&\n$MsgBatchExchangeModificationResponse\"\xb0\x01\n\x13MsgSpotMarketLaunch\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12K\n\x08proposal\x18\x02 \x01(\x0b\x32/.injective.exchange.v2.SpotMarketLaunchProposalR\x08proposal:4\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1c\x65xchange/MsgSpotMarketLaunch\"\x1d\n\x1bMsgSpotMarketLaunchResponse\"\xbf\x01\n\x18MsgPerpetualMarketLaunch\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12P\n\x08proposal\x18\x02 \x01(\x0b\x32\x34.injective.exchange.v2.PerpetualMarketLaunchProposalR\x08proposal:9\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*!exchange/MsgPerpetualMarketLaunch\"\"\n MsgPerpetualMarketLaunchResponse\"\xcb\x01\n\x1cMsgExpiryFuturesMarketLaunch\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12T\n\x08proposal\x18\x02 \x01(\x0b\x32\x38.injective.exchange.v2.ExpiryFuturesMarketLaunchProposalR\x08proposal:=\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*%exchange/MsgExpiryFuturesMarketLaunch\"&\n$MsgExpiryFuturesMarketLaunchResponse\"\xcb\x01\n\x1cMsgBinaryOptionsMarketLaunch\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12T\n\x08proposal\x18\x02 \x01(\x0b\x32\x38.injective.exchange.v2.BinaryOptionsMarketLaunchProposalR\x08proposal:=\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*%exchange/MsgBinaryOptionsMarketLaunch\"&\n$MsgBinaryOptionsMarketLaunchResponse\"\xc5\x01\n\x1aMsgBatchCommunityPoolSpend\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12R\n\x08proposal\x18\x02 \x01(\x0b\x32\x36.injective.exchange.v2.BatchCommunityPoolSpendProposalR\x08proposal:;\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*#exchange/MsgBatchCommunityPoolSpend\"$\n\"MsgBatchCommunityPoolSpendResponse\"\xbf\x01\n\x18MsgSpotMarketParamUpdate\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12P\n\x08proposal\x18\x02 \x01(\x0b\x32\x34.injective.exchange.v2.SpotMarketParamUpdateProposalR\x08proposal:9\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*!exchange/MsgSpotMarketParamUpdate\"\"\n MsgSpotMarketParamUpdateResponse\"\xd1\x01\n\x1eMsgDerivativeMarketParamUpdate\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12V\n\x08proposal\x18\x02 \x01(\x0b\x32:.injective.exchange.v2.DerivativeMarketParamUpdateProposalR\x08proposal:?\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\'exchange/MsgDerivativeMarketParamUpdate\"(\n&MsgDerivativeMarketParamUpdateResponse\"\xda\x01\n!MsgBinaryOptionsMarketParamUpdate\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12Y\n\x08proposal\x18\x02 \x01(\x0b\x32=.injective.exchange.v2.BinaryOptionsMarketParamUpdateProposalR\x08proposal:B\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0**exchange/MsgBinaryOptionsMarketParamUpdate\"+\n)MsgBinaryOptionsMarketParamUpdateResponse\"\xc2\x01\n\x19MsgMarketForcedSettlement\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12Q\n\x08proposal\x18\x02 \x01(\x0b\x32\x35.injective.exchange.v2.MarketForcedSettlementProposalR\x08proposal::\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\"exchange/MsgMarketForcedSettlement\"#\n!MsgMarketForcedSettlementResponse\"\xd1\x01\n\x1eMsgTradingRewardCampaignLaunch\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12V\n\x08proposal\x18\x02 \x01(\x0b\x32:.injective.exchange.v2.TradingRewardCampaignLaunchProposalR\x08proposal:?\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\'exchange/MsgTradingRewardCampaignLaunch\"(\n&MsgTradingRewardCampaignLaunchResponse\"\xaa\x01\n\x11MsgExchangeEnable\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12I\n\x08proposal\x18\x02 \x01(\x0b\x32-.injective.exchange.v2.ExchangeEnableProposalR\x08proposal:2\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1a\x65xchange/MsgExchangeEnable\"\x1b\n\x19MsgExchangeEnableResponse\"\xd1\x01\n\x1eMsgTradingRewardCampaignUpdate\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12V\n\x08proposal\x18\x02 \x01(\x0b\x32:.injective.exchange.v2.TradingRewardCampaignUpdateProposalR\x08proposal:?\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\'exchange/MsgTradingRewardCampaignUpdate\"(\n&MsgTradingRewardCampaignUpdateResponse\"\xe0\x01\n#MsgTradingRewardPendingPointsUpdate\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12[\n\x08proposal\x18\x02 \x01(\x0b\x32?.injective.exchange.v2.TradingRewardPendingPointsUpdateProposalR\x08proposal:D\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*,exchange/MsgTradingRewardPendingPointsUpdate\"-\n+MsgTradingRewardPendingPointsUpdateResponse\"\xa1\x01\n\x0eMsgFeeDiscount\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x46\n\x08proposal\x18\x02 \x01(\x0b\x32*.injective.exchange.v2.FeeDiscountProposalR\x08proposal:/\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x17\x65xchange/MsgFeeDiscount\"\x18\n\x16MsgFeeDiscountResponse\"\xf2\x01\n)MsgAtomicMarketOrderFeeMultiplierSchedule\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x61\n\x08proposal\x18\x02 \x01(\x0b\x32\x45.injective.exchange.v2.AtomicMarketOrderFeeMultiplierScheduleProposalR\x08proposal:J\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*2exchange/MsgAtomicMarketOrderFeeMultiplierSchedule\"3\n1MsgAtomicMarketOrderFeeMultiplierScheduleResponse2\xc1\x36\n\x03Msg\x12W\n\x07\x44\x65posit\x12!.injective.exchange.v2.MsgDeposit\x1a).injective.exchange.v2.MsgDepositResponse\x12Z\n\x08Withdraw\x12\".injective.exchange.v2.MsgWithdraw\x1a*.injective.exchange.v2.MsgWithdrawResponse\x12\x87\x01\n\x17InstantSpotMarketLaunch\x12\x31.injective.exchange.v2.MsgInstantSpotMarketLaunch\x1a\x39.injective.exchange.v2.MsgInstantSpotMarketLaunchResponse\x12\x96\x01\n\x1cInstantPerpetualMarketLaunch\x12\x36.injective.exchange.v2.MsgInstantPerpetualMarketLaunch\x1a>.injective.exchange.v2.MsgInstantPerpetualMarketLaunchResponse\x12\xa2\x01\n InstantExpiryFuturesMarketLaunch\x12:.injective.exchange.v2.MsgInstantExpiryFuturesMarketLaunch\x1a\x42.injective.exchange.v2.MsgInstantExpiryFuturesMarketLaunchResponse\x12~\n\x14\x43reateSpotLimitOrder\x12..injective.exchange.v2.MsgCreateSpotLimitOrder\x1a\x36.injective.exchange.v2.MsgCreateSpotLimitOrderResponse\x12\x90\x01\n\x1a\x42\x61tchCreateSpotLimitOrders\x12\x34.injective.exchange.v2.MsgBatchCreateSpotLimitOrders\x1a<.injective.exchange.v2.MsgBatchCreateSpotLimitOrdersResponse\x12\x81\x01\n\x15\x43reateSpotMarketOrder\x12/.injective.exchange.v2.MsgCreateSpotMarketOrder\x1a\x37.injective.exchange.v2.MsgCreateSpotMarketOrderResponse\x12o\n\x0f\x43\x61ncelSpotOrder\x12).injective.exchange.v2.MsgCancelSpotOrder\x1a\x31.injective.exchange.v2.MsgCancelSpotOrderResponse\x12\x81\x01\n\x15\x42\x61tchCancelSpotOrders\x12/.injective.exchange.v2.MsgBatchCancelSpotOrders\x1a\x37.injective.exchange.v2.MsgBatchCancelSpotOrdersResponse\x12u\n\x11\x42\x61tchUpdateOrders\x12+.injective.exchange.v2.MsgBatchUpdateOrders\x1a\x33.injective.exchange.v2.MsgBatchUpdateOrdersResponse\x12\x8d\x01\n\x19PrivilegedExecuteContract\x12\x33.injective.exchange.v2.MsgPrivilegedExecuteContract\x1a;.injective.exchange.v2.MsgPrivilegedExecuteContractResponse\x12\x90\x01\n\x1a\x43reateDerivativeLimitOrder\x12\x34.injective.exchange.v2.MsgCreateDerivativeLimitOrder\x1a<.injective.exchange.v2.MsgCreateDerivativeLimitOrderResponse\x12\xa2\x01\n BatchCreateDerivativeLimitOrders\x12:.injective.exchange.v2.MsgBatchCreateDerivativeLimitOrders\x1a\x42.injective.exchange.v2.MsgBatchCreateDerivativeLimitOrdersResponse\x12\x93\x01\n\x1b\x43reateDerivativeMarketOrder\x12\x35.injective.exchange.v2.MsgCreateDerivativeMarketOrder\x1a=.injective.exchange.v2.MsgCreateDerivativeMarketOrderResponse\x12\x81\x01\n\x15\x43\x61ncelDerivativeOrder\x12/.injective.exchange.v2.MsgCancelDerivativeOrder\x1a\x37.injective.exchange.v2.MsgCancelDerivativeOrderResponse\x12\x93\x01\n\x1b\x42\x61tchCancelDerivativeOrders\x12\x35.injective.exchange.v2.MsgBatchCancelDerivativeOrders\x1a=.injective.exchange.v2.MsgBatchCancelDerivativeOrdersResponse\x12\xa2\x01\n InstantBinaryOptionsMarketLaunch\x12:.injective.exchange.v2.MsgInstantBinaryOptionsMarketLaunch\x1a\x42.injective.exchange.v2.MsgInstantBinaryOptionsMarketLaunchResponse\x12\x99\x01\n\x1d\x43reateBinaryOptionsLimitOrder\x12\x37.injective.exchange.v2.MsgCreateBinaryOptionsLimitOrder\x1a?.injective.exchange.v2.MsgCreateBinaryOptionsLimitOrderResponse\x12\x9c\x01\n\x1e\x43reateBinaryOptionsMarketOrder\x12\x38.injective.exchange.v2.MsgCreateBinaryOptionsMarketOrder\x1a@.injective.exchange.v2.MsgCreateBinaryOptionsMarketOrderResponse\x12\x8a\x01\n\x18\x43\x61ncelBinaryOptionsOrder\x12\x32.injective.exchange.v2.MsgCancelBinaryOptionsOrder\x1a:.injective.exchange.v2.MsgCancelBinaryOptionsOrderResponse\x12\x9c\x01\n\x1e\x42\x61tchCancelBinaryOptionsOrders\x12\x38.injective.exchange.v2.MsgBatchCancelBinaryOptionsOrders\x1a@.injective.exchange.v2.MsgBatchCancelBinaryOptionsOrdersResponse\x12x\n\x12SubaccountTransfer\x12,.injective.exchange.v2.MsgSubaccountTransfer\x1a\x34.injective.exchange.v2.MsgSubaccountTransferResponse\x12r\n\x10\x45xternalTransfer\x12*.injective.exchange.v2.MsgExternalTransfer\x1a\x32.injective.exchange.v2.MsgExternalTransferResponse\x12u\n\x11LiquidatePosition\x12+.injective.exchange.v2.MsgLiquidatePosition\x1a\x33.injective.exchange.v2.MsgLiquidatePositionResponse\x12\x81\x01\n\x15\x45mergencySettleMarket\x12/.injective.exchange.v2.MsgEmergencySettleMarket\x1a\x37.injective.exchange.v2.MsgEmergencySettleMarketResponse\x12\x84\x01\n\x16IncreasePositionMargin\x12\x30.injective.exchange.v2.MsgIncreasePositionMargin\x1a\x38.injective.exchange.v2.MsgIncreasePositionMarginResponse\x12\x84\x01\n\x16\x44\x65\x63reasePositionMargin\x12\x30.injective.exchange.v2.MsgDecreasePositionMargin\x1a\x38.injective.exchange.v2.MsgDecreasePositionMarginResponse\x12i\n\rRewardsOptOut\x12\'.injective.exchange.v2.MsgRewardsOptOut\x1a/.injective.exchange.v2.MsgRewardsOptOutResponse\x12\x9c\x01\n\x1e\x41\x64minUpdateBinaryOptionsMarket\x12\x38.injective.exchange.v2.MsgAdminUpdateBinaryOptionsMarket\x1a@.injective.exchange.v2.MsgAdminUpdateBinaryOptionsMarketResponse\x12\x66\n\x0cUpdateParams\x12&.injective.exchange.v2.MsgUpdateParams\x1a..injective.exchange.v2.MsgUpdateParamsResponse\x12r\n\x10UpdateSpotMarket\x12*.injective.exchange.v2.MsgUpdateSpotMarket\x1a\x32.injective.exchange.v2.MsgUpdateSpotMarketResponse\x12\x84\x01\n\x16UpdateDerivativeMarket\x12\x30.injective.exchange.v2.MsgUpdateDerivativeMarket\x1a\x38.injective.exchange.v2.MsgUpdateDerivativeMarketResponse\x12~\n\x14\x41uthorizeStakeGrants\x12..injective.exchange.v2.MsgAuthorizeStakeGrants\x1a\x36.injective.exchange.v2.MsgAuthorizeStakeGrantsResponse\x12x\n\x12\x41\x63tivateStakeGrant\x12,.injective.exchange.v2.MsgActivateStakeGrant\x1a\x34.injective.exchange.v2.MsgActivateStakeGrantResponse\x12\x8d\x01\n\x19\x42\x61tchExchangeModification\x12\x33.injective.exchange.v2.MsgBatchExchangeModification\x1a;.injective.exchange.v2.MsgBatchExchangeModificationResponse\x12r\n\x10LaunchSpotMarket\x12*.injective.exchange.v2.MsgSpotMarketLaunch\x1a\x32.injective.exchange.v2.MsgSpotMarketLaunchResponse\x12\x81\x01\n\x15LaunchPerpetualMarket\x12/.injective.exchange.v2.MsgPerpetualMarketLaunch\x1a\x37.injective.exchange.v2.MsgPerpetualMarketLaunchResponse\x12\x8d\x01\n\x19LaunchExpiryFuturesMarket\x12\x33.injective.exchange.v2.MsgExpiryFuturesMarketLaunch\x1a;.injective.exchange.v2.MsgExpiryFuturesMarketLaunchResponse\x12\x8d\x01\n\x19LaunchBinaryOptionsMarket\x12\x33.injective.exchange.v2.MsgBinaryOptionsMarketLaunch\x1a;.injective.exchange.v2.MsgBinaryOptionsMarketLaunchResponse\x12\x87\x01\n\x17\x42\x61tchSpendCommunityPool\x12\x31.injective.exchange.v2.MsgBatchCommunityPoolSpend\x1a\x39.injective.exchange.v2.MsgBatchCommunityPoolSpendResponse\x12\x81\x01\n\x15SpotMarketParamUpdate\x12/.injective.exchange.v2.MsgSpotMarketParamUpdate\x1a\x37.injective.exchange.v2.MsgSpotMarketParamUpdateResponse\x12\x93\x01\n\x1b\x44\x65rivativeMarketParamUpdate\x12\x35.injective.exchange.v2.MsgDerivativeMarketParamUpdate\x1a=.injective.exchange.v2.MsgDerivativeMarketParamUpdateResponse\x12\x9c\x01\n\x1e\x42inaryOptionsMarketParamUpdate\x12\x38.injective.exchange.v2.MsgBinaryOptionsMarketParamUpdate\x1a@.injective.exchange.v2.MsgBinaryOptionsMarketParamUpdateResponse\x12\x7f\n\x11\x46orceSettleMarket\x12\x30.injective.exchange.v2.MsgMarketForcedSettlement\x1a\x38.injective.exchange.v2.MsgMarketForcedSettlementResponse\x12\x93\x01\n\x1bLaunchTradingRewardCampaign\x12\x35.injective.exchange.v2.MsgTradingRewardCampaignLaunch\x1a=.injective.exchange.v2.MsgTradingRewardCampaignLaunchResponse\x12l\n\x0e\x45nableExchange\x12(.injective.exchange.v2.MsgExchangeEnable\x1a\x30.injective.exchange.v2.MsgExchangeEnableResponse\x12\x93\x01\n\x1bUpdateTradingRewardCampaign\x12\x35.injective.exchange.v2.MsgTradingRewardCampaignUpdate\x1a=.injective.exchange.v2.MsgTradingRewardCampaignUpdateResponse\x12\xa2\x01\n UpdateTradingRewardPendingPoints\x12:.injective.exchange.v2.MsgTradingRewardPendingPointsUpdate\x1a\x42.injective.exchange.v2.MsgTradingRewardPendingPointsUpdateResponse\x12i\n\x11UpdateFeeDiscount\x12%.injective.exchange.v2.MsgFeeDiscount\x1a-.injective.exchange.v2.MsgFeeDiscountResponse\x12\xba\x01\n,UpdateAtomicMarketOrderFeeMultiplierSchedule\x12@.injective.exchange.v2.MsgAtomicMarketOrderFeeMultiplierSchedule\x1aH.injective.exchange.v2.MsgAtomicMarketOrderFeeMultiplierScheduleResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xed\x01\n\x19\x63om.injective.exchange.v2B\x07TxProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\xa2\x02\x03IEX\xaa\x02\x15Injective.Exchange.V2\xca\x02\x15Injective\\Exchange\\V2\xe2\x02!Injective\\Exchange\\V2\\GPBMetadata\xea\x02\x17Injective::Exchange::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v2.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective.exchange.v2B\007TxProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\242\002\003IEX\252\002\025Injective.Exchange.V2\312\002\025Injective\\Exchange\\V2\342\002!Injective\\Exchange\\V2\\GPBMetadata\352\002\027Injective::Exchange::V2'
  _globals['_MSGUPDATESPOTMARKET'].fields_by_name['new_min_price_tick_size']._loaded_options = None
  _globals['_MSGUPDATESPOTMARKET'].fields_by_name['new_min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGUPDATESPOTMARKET'].fields_by_name['new_min_quantity_tick_size']._loaded_options = None
  _globals['_MSGUPDATESPOTMARKET'].fields_by_name['new_min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGUPDATESPOTMARKET'].fields_by_name['new_min_notional']._loaded_options = None
  _globals['_MSGUPDATESPOTMARKET'].fields_by_name['new_min_notional']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGUPDATESPOTMARKET']._loaded_options = None
  _globals['_MSGUPDATESPOTMARKET']._serialized_options = b'\350\240\037\000\202\347\260*\005admin\212\347\260*\034exchange/MsgUpdateSpotMarket'
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_min_price_tick_size']._loaded_options = None
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_min_quantity_tick_size']._loaded_options = None
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_min_notional']._loaded_options = None
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_min_notional']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_initial_margin_ratio']._loaded_options = None
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_initial_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_maintenance_margin_ratio']._loaded_options = None
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_maintenance_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_reduce_margin_ratio']._loaded_options = None
  _globals['_MSGUPDATEDERIVATIVEMARKET'].fields_by_name['new_reduce_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGUPDATEDERIVATIVEMARKET']._loaded_options = None
  _globals['_MSGUPDATEDERIVATIVEMARKET']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\005admin\212\347\260*\"exchange/MsgUpdateDerivativeMarket'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\030exchange/MsgUpdateParams'
  _globals['_MSGDEPOSIT'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGDEPOSIT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_MSGDEPOSIT']._loaded_options = None
  _globals['_MSGDEPOSIT']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\023exchange/MsgDeposit'
  _globals['_MSGWITHDRAW'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGWITHDRAW'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_MSGWITHDRAW']._loaded_options = None
  _globals['_MSGWITHDRAW']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\024exchange/MsgWithdraw'
  _globals['_MSGCREATESPOTLIMITORDER'].fields_by_name['order']._loaded_options = None
  _globals['_MSGCREATESPOTLIMITORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATESPOTLIMITORDER']._loaded_options = None
  _globals['_MSGCREATESPOTLIMITORDER']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260* exchange/MsgCreateSpotLimitOrder'
  _globals['_MSGCREATESPOTLIMITORDERRESPONSE']._loaded_options = None
  _globals['_MSGCREATESPOTLIMITORDERRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGBATCHCREATESPOTLIMITORDERS'].fields_by_name['orders']._loaded_options = None
  _globals['_MSGBATCHCREATESPOTLIMITORDERS'].fields_by_name['orders']._serialized_options = b'\310\336\037\000'
  _globals['_MSGBATCHCREATESPOTLIMITORDERS']._loaded_options = None
  _globals['_MSGBATCHCREATESPOTLIMITORDERS']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*&exchange/MsgBatchCreateSpotLimitOrders'
  _globals['_MSGBATCHCREATESPOTLIMITORDERSRESPONSE']._loaded_options = None
  _globals['_MSGBATCHCREATESPOTLIMITORDERSRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGINSTANTSPOTMARKETLAUNCH'].fields_by_name['min_price_tick_size']._loaded_options = None
  _globals['_MSGINSTANTSPOTMARKETLAUNCH'].fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTSPOTMARKETLAUNCH'].fields_by_name['min_quantity_tick_size']._loaded_options = None
  _globals['_MSGINSTANTSPOTMARKETLAUNCH'].fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTSPOTMARKETLAUNCH'].fields_by_name['min_notional']._loaded_options = None
  _globals['_MSGINSTANTSPOTMARKETLAUNCH'].fields_by_name['min_notional']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTSPOTMARKETLAUNCH']._loaded_options = None
  _globals['_MSGINSTANTSPOTMARKETLAUNCH']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*#exchange/MsgInstantSpotMarketLaunch'
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['maker_fee_rate']._loaded_options = None
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['taker_fee_rate']._loaded_options = None
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['initial_margin_ratio']._loaded_options = None
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['initial_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['maintenance_margin_ratio']._loaded_options = None
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['maintenance_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['min_price_tick_size']._loaded_options = None
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['min_quantity_tick_size']._loaded_options = None
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['min_notional']._loaded_options = None
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['min_notional']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['reduce_margin_ratio']._loaded_options = None
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH'].fields_by_name['reduce_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH']._loaded_options = None
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*(exchange/MsgInstantPerpetualMarketLaunch'
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH'].fields_by_name['maker_fee_rate']._loaded_options = None
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH'].fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH'].fields_by_name['taker_fee_rate']._loaded_options = None
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH'].fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH'].fields_by_name['min_price_tick_size']._loaded_options = None
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH'].fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH'].fields_by_name['min_quantity_tick_size']._loaded_options = None
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH'].fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH'].fields_by_name['min_notional']._loaded_options = None
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH'].fields_by_name['min_notional']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH']._loaded_options = None
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*,exchange/MsgInstantBinaryOptionsMarketLaunch'
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['maker_fee_rate']._loaded_options = None
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['taker_fee_rate']._loaded_options = None
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['initial_margin_ratio']._loaded_options = None
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['initial_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['maintenance_margin_ratio']._loaded_options = None
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['maintenance_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['min_price_tick_size']._loaded_options = None
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['min_quantity_tick_size']._loaded_options = None
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['min_notional']._loaded_options = None
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['min_notional']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['reduce_margin_ratio']._loaded_options = None
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH'].fields_by_name['reduce_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH']._loaded_options = None
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*,exchange/MsgInstantExpiryFuturesMarketLaunch'
  _globals['_MSGCREATESPOTMARKETORDER'].fields_by_name['order']._loaded_options = None
  _globals['_MSGCREATESPOTMARKETORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATESPOTMARKETORDER']._loaded_options = None
  _globals['_MSGCREATESPOTMARKETORDER']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*!exchange/MsgCreateSpotMarketOrder'
  _globals['_MSGCREATESPOTMARKETORDERRESPONSE'].fields_by_name['results']._loaded_options = None
  _globals['_MSGCREATESPOTMARKETORDERRESPONSE'].fields_by_name['results']._serialized_options = b'\310\336\037\001'
  _globals['_MSGCREATESPOTMARKETORDERRESPONSE']._loaded_options = None
  _globals['_MSGCREATESPOTMARKETORDERRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_SPOTMARKETORDERRESULTS'].fields_by_name['quantity']._loaded_options = None
  _globals['_SPOTMARKETORDERRESULTS'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTMARKETORDERRESULTS'].fields_by_name['price']._loaded_options = None
  _globals['_SPOTMARKETORDERRESULTS'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTMARKETORDERRESULTS'].fields_by_name['fee']._loaded_options = None
  _globals['_SPOTMARKETORDERRESULTS'].fields_by_name['fee']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTMARKETORDERRESULTS']._loaded_options = None
  _globals['_SPOTMARKETORDERRESULTS']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGCREATEDERIVATIVELIMITORDER'].fields_by_name['order']._loaded_options = None
  _globals['_MSGCREATEDERIVATIVELIMITORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEDERIVATIVELIMITORDER']._loaded_options = None
  _globals['_MSGCREATEDERIVATIVELIMITORDER']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260*&exchange/MsgCreateDerivativeLimitOrder'
  _globals['_MSGCREATEDERIVATIVELIMITORDERRESPONSE']._loaded_options = None
  _globals['_MSGCREATEDERIVATIVELIMITORDERRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDER'].fields_by_name['order']._loaded_options = None
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDER']._loaded_options = None
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDER']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260*)exchange/MsgCreateBinaryOptionsLimitOrder'
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE']._loaded_options = None
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERS'].fields_by_name['orders']._loaded_options = None
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERS'].fields_by_name['orders']._serialized_options = b'\310\336\037\000'
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERS']._loaded_options = None
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERS']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260*,exchange/MsgBatchCreateDerivativeLimitOrders'
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE']._loaded_options = None
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGCANCELSPOTORDER']._loaded_options = None
  _globals['_MSGCANCELSPOTORDER']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260*\033exchange/MsgCancelSpotOrder'
  _globals['_MSGBATCHCANCELSPOTORDERS'].fields_by_name['data']._loaded_options = None
  _globals['_MSGBATCHCANCELSPOTORDERS'].fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _globals['_MSGBATCHCANCELSPOTORDERS']._loaded_options = None
  _globals['_MSGBATCHCANCELSPOTORDERS']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260*!exchange/MsgBatchCancelSpotOrders'
  _globals['_MSGBATCHCANCELSPOTORDERSRESPONSE']._loaded_options = None
  _globals['_MSGBATCHCANCELSPOTORDERSRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERS'].fields_by_name['data']._loaded_options = None
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERS'].fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERS']._loaded_options = None
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERS']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260**exchange/MsgBatchCancelBinaryOptionsOrders'
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE']._loaded_options = None
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['spot_orders_to_cancel']._loaded_options = None
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['spot_orders_to_cancel']._serialized_options = b'\310\336\037\001'
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['derivative_orders_to_cancel']._loaded_options = None
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['derivative_orders_to_cancel']._serialized_options = b'\310\336\037\001'
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['spot_orders_to_create']._loaded_options = None
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['spot_orders_to_create']._serialized_options = b'\310\336\037\001'
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['derivative_orders_to_create']._loaded_options = None
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['derivative_orders_to_create']._serialized_options = b'\310\336\037\001'
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['binary_options_orders_to_cancel']._loaded_options = None
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['binary_options_orders_to_cancel']._serialized_options = b'\310\336\037\001'
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['binary_options_orders_to_create']._loaded_options = None
  _globals['_MSGBATCHUPDATEORDERS'].fields_by_name['binary_options_orders_to_create']._serialized_options = b'\310\336\037\001'
  _globals['_MSGBATCHUPDATEORDERS']._loaded_options = None
  _globals['_MSGBATCHUPDATEORDERS']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260*\035exchange/MsgBatchUpdateOrders'
  _globals['_MSGBATCHUPDATEORDERSRESPONSE']._loaded_options = None
  _globals['_MSGBATCHUPDATEORDERSRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGCREATEDERIVATIVEMARKETORDER'].fields_by_name['order']._loaded_options = None
  _globals['_MSGCREATEDERIVATIVEMARKETORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEDERIVATIVEMARKETORDER']._loaded_options = None
  _globals['_MSGCREATEDERIVATIVEMARKETORDER']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260*\'exchange/MsgCreateDerivativeMarketOrder'
  _globals['_MSGCREATEDERIVATIVEMARKETORDERRESPONSE'].fields_by_name['results']._loaded_options = None
  _globals['_MSGCREATEDERIVATIVEMARKETORDERRESPONSE'].fields_by_name['results']._serialized_options = b'\310\336\037\001'
  _globals['_MSGCREATEDERIVATIVEMARKETORDERRESPONSE']._loaded_options = None
  _globals['_MSGCREATEDERIVATIVEMARKETORDERRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_DERIVATIVEMARKETORDERRESULTS'].fields_by_name['quantity']._loaded_options = None
  _globals['_DERIVATIVEMARKETORDERRESULTS'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKETORDERRESULTS'].fields_by_name['price']._loaded_options = None
  _globals['_DERIVATIVEMARKETORDERRESULTS'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKETORDERRESULTS'].fields_by_name['fee']._loaded_options = None
  _globals['_DERIVATIVEMARKETORDERRESULTS'].fields_by_name['fee']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKETORDERRESULTS'].fields_by_name['position_delta']._loaded_options = None
  _globals['_DERIVATIVEMARKETORDERRESULTS'].fields_by_name['position_delta']._serialized_options = b'\310\336\037\000'
  _globals['_DERIVATIVEMARKETORDERRESULTS'].fields_by_name['payout']._loaded_options = None
  _globals['_DERIVATIVEMARKETORDERRESULTS'].fields_by_name['payout']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVEMARKETORDERRESULTS']._loaded_options = None
  _globals['_DERIVATIVEMARKETORDERRESULTS']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDER'].fields_by_name['order']._loaded_options = None
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDER']._loaded_options = None
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDER']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260**exchange/MsgCreateBinaryOptionsMarketOrder'
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE'].fields_by_name['results']._loaded_options = None
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE'].fields_by_name['results']._serialized_options = b'\310\336\037\001'
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE']._loaded_options = None
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGCANCELDERIVATIVEORDER']._loaded_options = None
  _globals['_MSGCANCELDERIVATIVEORDER']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260*!exchange/MsgCancelDerivativeOrder'
  _globals['_MSGCANCELBINARYOPTIONSORDER']._loaded_options = None
  _globals['_MSGCANCELBINARYOPTIONSORDER']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260*$exchange/MsgCancelBinaryOptionsOrder'
  _globals['_MSGBATCHCANCELDERIVATIVEORDERS'].fields_by_name['data']._loaded_options = None
  _globals['_MSGBATCHCANCELDERIVATIVEORDERS'].fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _globals['_MSGBATCHCANCELDERIVATIVEORDERS']._loaded_options = None
  _globals['_MSGBATCHCANCELDERIVATIVEORDERS']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260*\'exchange/MsgBatchCancelDerivativeOrders'
  _globals['_MSGBATCHCANCELDERIVATIVEORDERSRESPONSE']._loaded_options = None
  _globals['_MSGBATCHCANCELDERIVATIVEORDERSRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGSUBACCOUNTTRANSFER'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGSUBACCOUNTTRANSFER'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSUBACCOUNTTRANSFER']._loaded_options = None
  _globals['_MSGSUBACCOUNTTRANSFER']._serialized_options = b'\202\347\260*\006sender\212\347\260*\036exchange/MsgSubaccountTransfer'
  _globals['_MSGEXTERNALTRANSFER'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGEXTERNALTRANSFER'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_MSGEXTERNALTRANSFER']._loaded_options = None
  _globals['_MSGEXTERNALTRANSFER']._serialized_options = b'\202\347\260*\006sender\212\347\260*\034exchange/MsgExternalTransfer'
  _globals['_MSGLIQUIDATEPOSITION'].fields_by_name['order']._loaded_options = None
  _globals['_MSGLIQUIDATEPOSITION'].fields_by_name['order']._serialized_options = b'\310\336\037\001'
  _globals['_MSGLIQUIDATEPOSITION']._loaded_options = None
  _globals['_MSGLIQUIDATEPOSITION']._serialized_options = b'\202\347\260*\006sender\212\347\260*\035exchange/MsgLiquidatePosition'
  _globals['_MSGEMERGENCYSETTLEMARKET']._loaded_options = None
  _globals['_MSGEMERGENCYSETTLEMARKET']._serialized_options = b'\202\347\260*\006sender\212\347\260*!exchange/MsgEmergencySettleMarket'
  _globals['_MSGINCREASEPOSITIONMARGIN'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGINCREASEPOSITIONMARGIN'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGINCREASEPOSITIONMARGIN']._loaded_options = None
  _globals['_MSGINCREASEPOSITIONMARGIN']._serialized_options = b'\202\347\260*\006sender\212\347\260*\"exchange/MsgIncreasePositionMargin'
  _globals['_MSGDECREASEPOSITIONMARGIN'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGDECREASEPOSITIONMARGIN'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGDECREASEPOSITIONMARGIN']._loaded_options = None
  _globals['_MSGDECREASEPOSITIONMARGIN']._serialized_options = b'\202\347\260*\006sender\212\347\260*\"exchange/MsgDecreasePositionMargin'
  _globals['_MSGPRIVILEGEDEXECUTECONTRACT']._loaded_options = None
  _globals['_MSGPRIVILEGEDEXECUTECONTRACT']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*%exchange/MsgPrivilegedExecuteContract'
  _globals['_MSGPRIVILEGEDEXECUTECONTRACTRESPONSE'].fields_by_name['funds_diff']._loaded_options = None
  _globals['_MSGPRIVILEGEDEXECUTECONTRACTRESPONSE'].fields_by_name['funds_diff']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_MSGPRIVILEGEDEXECUTECONTRACTRESPONSE']._loaded_options = None
  _globals['_MSGPRIVILEGEDEXECUTECONTRACTRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _globals['_MSGREWARDSOPTOUT']._loaded_options = None
  _globals['_MSGREWARDSOPTOUT']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\031exchange/MsgRewardsOptOut'
  _globals['_MSGRECLAIMLOCKEDFUNDS']._loaded_options = None
  _globals['_MSGRECLAIMLOCKEDFUNDS']._serialized_options = b'\202\347\260*\006sender\212\347\260*\036exchange/MsgReclaimLockedFunds'
  _globals['_MSGSIGNDATA'].fields_by_name['Signer']._loaded_options = None
  _globals['_MSGSIGNDATA'].fields_by_name['Signer']._serialized_options = b'\352\336\037\006signer\372\336\037-github.com/cosmos/cosmos-sdk/types.AccAddress'
  _globals['_MSGSIGNDATA'].fields_by_name['Data']._loaded_options = None
  _globals['_MSGSIGNDATA'].fields_by_name['Data']._serialized_options = b'\352\336\037\004data'
  _globals['_MSGSIGNDOC'].fields_by_name['sign_type']._loaded_options = None
  _globals['_MSGSIGNDOC'].fields_by_name['sign_type']._serialized_options = b'\352\336\037\004type'
  _globals['_MSGSIGNDOC'].fields_by_name['value']._loaded_options = None
  _globals['_MSGSIGNDOC'].fields_by_name['value']._serialized_options = b'\310\336\037\000'
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKET'].fields_by_name['settlement_price']._loaded_options = None
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKET'].fields_by_name['settlement_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKET']._loaded_options = None
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKET']._serialized_options = b'\202\347\260*\006sender\212\347\260**exchange/MsgAdminUpdateBinaryOptionsMarket'
  _globals['_MSGAUTHORIZESTAKEGRANTS']._loaded_options = None
  _globals['_MSGAUTHORIZESTAKEGRANTS']._serialized_options = b'\202\347\260*\006sender\212\347\260* exchange/MsgAuthorizeStakeGrants'
  _globals['_MSGACTIVATESTAKEGRANT']._loaded_options = None
  _globals['_MSGACTIVATESTAKEGRANT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\036exchange/MsgActivateStakeGrant'
  _globals['_MSGBATCHEXCHANGEMODIFICATION']._loaded_options = None
  _globals['_MSGBATCHEXCHANGEMODIFICATION']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*%exchange/MsgBatchExchangeModification'
  _globals['_MSGSPOTMARKETLAUNCH']._loaded_options = None
  _globals['_MSGSPOTMARKETLAUNCH']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\034exchange/MsgSpotMarketLaunch'
  _globals['_MSGPERPETUALMARKETLAUNCH']._loaded_options = None
  _globals['_MSGPERPETUALMARKETLAUNCH']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*!exchange/MsgPerpetualMarketLaunch'
  _globals['_MSGEXPIRYFUTURESMARKETLAUNCH']._loaded_options = None
  _globals['_MSGEXPIRYFUTURESMARKETLAUNCH']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*%exchange/MsgExpiryFuturesMarketLaunch'
  _globals['_MSGBINARYOPTIONSMARKETLAUNCH']._loaded_options = None
  _globals['_MSGBINARYOPTIONSMARKETLAUNCH']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*%exchange/MsgBinaryOptionsMarketLaunch'
  _globals['_MSGBATCHCOMMUNITYPOOLSPEND']._loaded_options = None
  _globals['_MSGBATCHCOMMUNITYPOOLSPEND']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*#exchange/MsgBatchCommunityPoolSpend'
  _globals['_MSGSPOTMARKETPARAMUPDATE']._loaded_options = None
  _globals['_MSGSPOTMARKETPARAMUPDATE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*!exchange/MsgSpotMarketParamUpdate'
  _globals['_MSGDERIVATIVEMARKETPARAMUPDATE']._loaded_options = None
  _globals['_MSGDERIVATIVEMARKETPARAMUPDATE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\'exchange/MsgDerivativeMarketParamUpdate'
  _globals['_MSGBINARYOPTIONSMARKETPARAMUPDATE']._loaded_options = None
  _globals['_MSGBINARYOPTIONSMARKETPARAMUPDATE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260**exchange/MsgBinaryOptionsMarketParamUpdate'
  _globals['_MSGMARKETFORCEDSETTLEMENT']._loaded_options = None
  _globals['_MSGMARKETFORCEDSETTLEMENT']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\"exchange/MsgMarketForcedSettlement'
  _globals['_MSGTRADINGREWARDCAMPAIGNLAUNCH']._loaded_options = None
  _globals['_MSGTRADINGREWARDCAMPAIGNLAUNCH']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\'exchange/MsgTradingRewardCampaignLaunch'
  _globals['_MSGEXCHANGEENABLE']._loaded_options = None
  _globals['_MSGEXCHANGEENABLE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\032exchange/MsgExchangeEnable'
  _globals['_MSGTRADINGREWARDCAMPAIGNUPDATE']._loaded_options = None
  _globals['_MSGTRADINGREWARDCAMPAIGNUPDATE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\'exchange/MsgTradingRewardCampaignUpdate'
  _globals['_MSGTRADINGREWARDPENDINGPOINTSUPDATE']._loaded_options = None
  _globals['_MSGTRADINGREWARDPENDINGPOINTSUPDATE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*,exchange/MsgTradingRewardPendingPointsUpdate'
  _globals['_MSGFEEDISCOUNT']._loaded_options = None
  _globals['_MSGFEEDISCOUNT']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\027exchange/MsgFeeDiscount'
  _globals['_MSGATOMICMARKETORDERFEEMULTIPLIERSCHEDULE']._loaded_options = None
  _globals['_MSGATOMICMARKETORDERFEEMULTIPLIERSCHEDULE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*2exchange/MsgAtomicMarketOrderFeeMultiplierSchedule'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATESPOTMARKET']._serialized_start=417
  _globals['_MSGUPDATESPOTMARKET']._serialized_end=836
  _globals['_MSGUPDATESPOTMARKETRESPONSE']._serialized_start=838
  _globals['_MSGUPDATESPOTMARKETRESPONSE']._serialized_end=867
  _globals['_MSGUPDATEDERIVATIVEMARKET']._serialized_start=870
  _globals['_MSGUPDATEDERIVATIVEMARKET']._serialized_end=1593
  _globals['_MSGUPDATEDERIVATIVEMARKETRESPONSE']._serialized_start=1595
  _globals['_MSGUPDATEDERIVATIVEMARKETRESPONSE']._serialized_end=1630
  _globals['_MSGUPDATEPARAMS']._serialized_start=1633
  _globals['_MSGUPDATEPARAMS']._serialized_end=1812
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1814
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1839
  _globals['_MSGDEPOSIT']._serialized_start=1842
  _globals['_MSGDEPOSIT']._serialized_end=2017
  _globals['_MSGDEPOSITRESPONSE']._serialized_start=2019
  _globals['_MSGDEPOSITRESPONSE']._serialized_end=2039
  _globals['_MSGWITHDRAW']._serialized_start=2042
  _globals['_MSGWITHDRAW']._serialized_end=2219
  _globals['_MSGWITHDRAWRESPONSE']._serialized_start=2221
  _globals['_MSGWITHDRAWRESPONSE']._serialized_end=2242
  _globals['_MSGCREATESPOTLIMITORDER']._serialized_start=2245
  _globals['_MSGCREATESPOTLIMITORDER']._serialized_end=2414
  _globals['_MSGCREATESPOTLIMITORDERRESPONSE']._serialized_start=2416
  _globals['_MSGCREATESPOTLIMITORDERRESPONSE']._serialized_end=2508
  _globals['_MSGBATCHCREATESPOTLIMITORDERS']._serialized_start=2511
  _globals['_MSGBATCHCREATESPOTLIMITORDERS']._serialized_end=2694
  _globals['_MSGBATCHCREATESPOTLIMITORDERSRESPONSE']._serialized_start=2697
  _globals['_MSGBATCHCREATESPOTLIMITORDERSRESPONSE']._serialized_end=2875
  _globals['_MSGINSTANTSPOTMARKETLAUNCH']._serialized_start=2878
  _globals['_MSGINSTANTSPOTMARKETLAUNCH']._serialized_end=3401
  _globals['_MSGINSTANTSPOTMARKETLAUNCHRESPONSE']._serialized_start=3403
  _globals['_MSGINSTANTSPOTMARKETLAUNCHRESPONSE']._serialized_end=3439
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH']._serialized_start=3442
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH']._serialized_end=4472
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCHRESPONSE']._serialized_start=4474
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCHRESPONSE']._serialized_end=4515
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH']._serialized_start=4518
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH']._serialized_end=5423
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCHRESPONSE']._serialized_start=5425
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCHRESPONSE']._serialized_end=5470
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH']._serialized_start=5473
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH']._serialized_end=6535
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCHRESPONSE']._serialized_start=6537
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCHRESPONSE']._serialized_end=6582
  _globals['_MSGCREATESPOTMARKETORDER']._serialized_start=6585
  _globals['_MSGCREATESPOTMARKETORDER']._serialized_end=6756
  _globals['_MSGCREATESPOTMARKETORDERRESPONSE']._serialized_start=6759
  _globals['_MSGCREATESPOTMARKETORDERRESPONSE']._serialized_end=6931
  _globals['_SPOTMARKETORDERRESULTS']._serialized_start=6934
  _globals['_SPOTMARKETORDERRESULTS']._serialized_end=7147
  _globals['_MSGCREATEDERIVATIVELIMITORDER']._serialized_start=7150
  _globals['_MSGCREATEDERIVATIVELIMITORDER']._serialized_end=7333
  _globals['_MSGCREATEDERIVATIVELIMITORDERRESPONSE']._serialized_start=7335
  _globals['_MSGCREATEDERIVATIVELIMITORDERRESPONSE']._serialized_end=7433
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDER']._serialized_start=7436
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDER']._serialized_end=7625
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE']._serialized_start=7627
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE']._serialized_end=7728
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERS']._serialized_start=7731
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERS']._serialized_end=7928
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE']._serialized_start=7931
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE']._serialized_end=8115
  _globals['_MSGCANCELSPOTORDER']._serialized_start=8118
  _globals['_MSGCANCELSPOTORDER']._serialized_end=8326
  _globals['_MSGCANCELSPOTORDERRESPONSE']._serialized_start=8328
  _globals['_MSGCANCELSPOTORDERRESPONSE']._serialized_end=8356
  _globals['_MSGBATCHCANCELSPOTORDERS']._serialized_start=8359
  _globals['_MSGBATCHCANCELSPOTORDERS']._serialized_end=8524
  _globals['_MSGBATCHCANCELSPOTORDERSRESPONSE']._serialized_start=8526
  _globals['_MSGBATCHCANCELSPOTORDERSRESPONSE']._serialized_end=8596
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERS']._serialized_start=8599
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERS']._serialized_end=8782
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE']._serialized_start=8784
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE']._serialized_end=8863
  _globals['_MSGBATCHUPDATEORDERS']._serialized_start=8866
  _globals['_MSGBATCHUPDATEORDERS']._serialized_end=9846
  _globals['_MSGBATCHUPDATEORDERSRESPONSE']._serialized_start=9849
  _globals['_MSGBATCHUPDATEORDERSRESPONSE']._serialized_end=10625
  _globals['_MSGCREATEDERIVATIVEMARKETORDER']._serialized_start=10628
  _globals['_MSGCREATEDERIVATIVEMARKETORDER']._serialized_end=10813
  _globals['_MSGCREATEDERIVATIVEMARKETORDERRESPONSE']._serialized_start=10816
  _globals['_MSGCREATEDERIVATIVEMARKETORDERRESPONSE']._serialized_end=11000
  _globals['_DERIVATIVEMARKETORDERRESULTS']._serialized_start=11003
  _globals['_DERIVATIVEMARKETORDERRESULTS']._serialized_end=11366
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDER']._serialized_start=11369
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDER']._serialized_end=11560
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE']._serialized_start=11563
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE']._serialized_end=11750
  _globals['_MSGCANCELDERIVATIVEORDER']._serialized_start=11753
  _globals['_MSGCANCELDERIVATIVEORDER']._serialized_end=12004
  _globals['_MSGCANCELDERIVATIVEORDERRESPONSE']._serialized_start=12006
  _globals['_MSGCANCELDERIVATIVEORDERRESPONSE']._serialized_end=12040
  _globals['_MSGCANCELBINARYOPTIONSORDER']._serialized_start=12043
  _globals['_MSGCANCELBINARYOPTIONSORDER']._serialized_end=12300
  _globals['_MSGCANCELBINARYOPTIONSORDERRESPONSE']._serialized_start=12302
  _globals['_MSGCANCELBINARYOPTIONSORDERRESPONSE']._serialized_end=12339
  _globals['_ORDERDATA']._serialized_start=12342
  _globals['_ORDERDATA']._serialized_end=12499
  _globals['_MSGBATCHCANCELDERIVATIVEORDERS']._serialized_start=12502
  _globals['_MSGBATCHCANCELDERIVATIVEORDERS']._serialized_end=12679
  _globals['_MSGBATCHCANCELDERIVATIVEORDERSRESPONSE']._serialized_start=12681
  _globals['_MSGBATCHCANCELDERIVATIVEORDERSRESPONSE']._serialized_end=12757
  _globals['_MSGSUBACCOUNTTRANSFER']._serialized_start=12760
  _globals['_MSGSUBACCOUNTTRANSFER']._serialized_end=13022
  _globals['_MSGSUBACCOUNTTRANSFERRESPONSE']._serialized_start=13024
  _globals['_MSGSUBACCOUNTTRANSFERRESPONSE']._serialized_end=13055
  _globals['_MSGEXTERNALTRANSFER']._serialized_start=13058
  _globals['_MSGEXTERNALTRANSFER']._serialized_end=13316
  _globals['_MSGEXTERNALTRANSFERRESPONSE']._serialized_start=13318
  _globals['_MSGEXTERNALTRANSFERRESPONSE']._serialized_end=13347
  _globals['_MSGLIQUIDATEPOSITION']._serialized_start=13350
  _globals['_MSGLIQUIDATEPOSITION']._serialized_end=13577
  _globals['_MSGLIQUIDATEPOSITIONRESPONSE']._serialized_start=13579
  _globals['_MSGLIQUIDATEPOSITIONRESPONSE']._serialized_end=13609
  _globals['_MSGEMERGENCYSETTLEMARKET']._serialized_start=13612
  _globals['_MSGEMERGENCYSETTLEMARKET']._serialized_end=13779
  _globals['_MSGEMERGENCYSETTLEMARKETRESPONSE']._serialized_start=13781
  _globals['_MSGEMERGENCYSETTLEMARKETRESPONSE']._serialized_end=13815
  _globals['_MSGINCREASEPOSITIONMARGIN']._serialized_start=13818
  _globals['_MSGINCREASEPOSITIONMARGIN']._serialized_end=14121
  _globals['_MSGINCREASEPOSITIONMARGINRESPONSE']._serialized_start=14123
  _globals['_MSGINCREASEPOSITIONMARGINRESPONSE']._serialized_end=14158
  _globals['_MSGDECREASEPOSITIONMARGIN']._serialized_start=14161
  _globals['_MSGDECREASEPOSITIONMARGIN']._serialized_end=14464
  _globals['_MSGDECREASEPOSITIONMARGINRESPONSE']._serialized_start=14466
  _globals['_MSGDECREASEPOSITIONMARGINRESPONSE']._serialized_end=14501
  _globals['_MSGPRIVILEGEDEXECUTECONTRACT']._serialized_start=14504
  _globals['_MSGPRIVILEGEDEXECUTECONTRACT']._serialized_end=14706
  _globals['_MSGPRIVILEGEDEXECUTECONTRACTRESPONSE']._serialized_start=14709
  _globals['_MSGPRIVILEGEDEXECUTECONTRACTRESPONSE']._serialized_end=14876
  _globals['_MSGREWARDSOPTOUT']._serialized_start=14878
  _globals['_MSGREWARDSOPTOUT']._serialized_end=14971
  _globals['_MSGREWARDSOPTOUTRESPONSE']._serialized_start=14973
  _globals['_MSGREWARDSOPTOUTRESPONSE']._serialized_end=14999
  _globals['_MSGRECLAIMLOCKEDFUNDS']._serialized_start=15002
  _globals['_MSGRECLAIMLOCKEDFUNDS']._serialized_end=15177
  _globals['_MSGRECLAIMLOCKEDFUNDSRESPONSE']._serialized_start=15179
  _globals['_MSGRECLAIMLOCKEDFUNDSRESPONSE']._serialized_end=15210
  _globals['_MSGSIGNDATA']._serialized_start=15213
  _globals['_MSGSIGNDATA']._serialized_end=15341
  _globals['_MSGSIGNDOC']._serialized_start=15343
  _globals['_MSGSIGNDOC']._serialized_end=15458
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKET']._serialized_start=15461
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKET']._serialized_end=15852
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKETRESPONSE']._serialized_start=15854
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKETRESPONSE']._serialized_end=15897
  _globals['_MSGAUTHORIZESTAKEGRANTS']._serialized_start=15900
  _globals['_MSGAUTHORIZESTAKEGRANTS']._serialized_end=16066
  _globals['_MSGAUTHORIZESTAKEGRANTSRESPONSE']._serialized_start=16068
  _globals['_MSGAUTHORIZESTAKEGRANTSRESPONSE']._serialized_end=16101
  _globals['_MSGACTIVATESTAKEGRANT']._serialized_start=16103
  _globals['_MSGACTIVATESTAKEGRANT']._serialized_end=16224
  _globals['_MSGACTIVATESTAKEGRANTRESPONSE']._serialized_start=16226
  _globals['_MSGACTIVATESTAKEGRANTRESPONSE']._serialized_end=16257
  _globals['_MSGBATCHEXCHANGEMODIFICATION']._serialized_start=16260
  _globals['_MSGBATCHEXCHANGEMODIFICATION']._serialized_end=16463
  _globals['_MSGBATCHEXCHANGEMODIFICATIONRESPONSE']._serialized_start=16465
  _globals['_MSGBATCHEXCHANGEMODIFICATIONRESPONSE']._serialized_end=16503
  _globals['_MSGSPOTMARKETLAUNCH']._serialized_start=16506
  _globals['_MSGSPOTMARKETLAUNCH']._serialized_end=16682
  _globals['_MSGSPOTMARKETLAUNCHRESPONSE']._serialized_start=16684
  _globals['_MSGSPOTMARKETLAUNCHRESPONSE']._serialized_end=16713
  _globals['_MSGPERPETUALMARKETLAUNCH']._serialized_start=16716
  _globals['_MSGPERPETUALMARKETLAUNCH']._serialized_end=16907
  _globals['_MSGPERPETUALMARKETLAUNCHRESPONSE']._serialized_start=16909
  _globals['_MSGPERPETUALMARKETLAUNCHRESPONSE']._serialized_end=16943
  _globals['_MSGEXPIRYFUTURESMARKETLAUNCH']._serialized_start=16946
  _globals['_MSGEXPIRYFUTURESMARKETLAUNCH']._serialized_end=17149
  _globals['_MSGEXPIRYFUTURESMARKETLAUNCHRESPONSE']._serialized_start=17151
  _globals['_MSGEXPIRYFUTURESMARKETLAUNCHRESPONSE']._serialized_end=17189
  _globals['_MSGBINARYOPTIONSMARKETLAUNCH']._serialized_start=17192
  _globals['_MSGBINARYOPTIONSMARKETLAUNCH']._serialized_end=17395
  _globals['_MSGBINARYOPTIONSMARKETLAUNCHRESPONSE']._serialized_start=17397
  _globals['_MSGBINARYOPTIONSMARKETLAUNCHRESPONSE']._serialized_end=17435
  _globals['_MSGBATCHCOMMUNITYPOOLSPEND']._serialized_start=17438
  _globals['_MSGBATCHCOMMUNITYPOOLSPEND']._serialized_end=17635
  _globals['_MSGBATCHCOMMUNITYPOOLSPENDRESPONSE']._serialized_start=17637
  _globals['_MSGBATCHCOMMUNITYPOOLSPENDRESPONSE']._serialized_end=17673
  _globals['_MSGSPOTMARKETPARAMUPDATE']._serialized_start=17676
  _globals['_MSGSPOTMARKETPARAMUPDATE']._serialized_end=17867
  _globals['_MSGSPOTMARKETPARAMUPDATERESPONSE']._serialized_start=17869
  _globals['_MSGSPOTMARKETPARAMUPDATERESPONSE']._serialized_end=17903
  _globals['_MSGDERIVATIVEMARKETPARAMUPDATE']._serialized_start=17906
  _globals['_MSGDERIVATIVEMARKETPARAMUPDATE']._serialized_end=18115
  _globals['_MSGDERIVATIVEMARKETPARAMUPDATERESPONSE']._serialized_start=18117
  _globals['_MSGDERIVATIVEMARKETPARAMUPDATERESPONSE']._serialized_end=18157
  _globals['_MSGBINARYOPTIONSMARKETPARAMUPDATE']._serialized_start=18160
  _globals['_MSGBINARYOPTIONSMARKETPARAMUPDATE']._serialized_end=18378
  _globals['_MSGBINARYOPTIONSMARKETPARAMUPDATERESPONSE']._serialized_start=18380
  _globals['_MSGBINARYOPTIONSMARKETPARAMUPDATERESPONSE']._serialized_end=18423
  _globals['_MSGMARKETFORCEDSETTLEMENT']._serialized_start=18426
  _globals['_MSGMARKETFORCEDSETTLEMENT']._serialized_end=18620
  _globals['_MSGMARKETFORCEDSETTLEMENTRESPONSE']._serialized_start=18622
  _globals['_MSGMARKETFORCEDSETTLEMENTRESPONSE']._serialized_end=18657
  _globals['_MSGTRADINGREWARDCAMPAIGNLAUNCH']._serialized_start=18660
  _globals['_MSGTRADINGREWARDCAMPAIGNLAUNCH']._serialized_end=18869
  _globals['_MSGTRADINGREWARDCAMPAIGNLAUNCHRESPONSE']._serialized_start=18871
  _globals['_MSGTRADINGREWARDCAMPAIGNLAUNCHRESPONSE']._serialized_end=18911
  _globals['_MSGEXCHANGEENABLE']._serialized_start=18914
  _globals['_MSGEXCHANGEENABLE']._serialized_end=19084
  _globals['_MSGEXCHANGEENABLERESPONSE']._serialized_start=19086
  _globals['_MSGEXCHANGEENABLERESPONSE']._serialized_end=19113
  _globals['_MSGTRADINGREWARDCAMPAIGNUPDATE']._serialized_start=19116
  _globals['_MSGTRADINGREWARDCAMPAIGNUPDATE']._serialized_end=19325
  _globals['_MSGTRADINGREWARDCAMPAIGNUPDATERESPONSE']._serialized_start=19327
  _globals['_MSGTRADINGREWARDCAMPAIGNUPDATERESPONSE']._serialized_end=19367
  _globals['_MSGTRADINGREWARDPENDINGPOINTSUPDATE']._serialized_start=19370
  _globals['_MSGTRADINGREWARDPENDINGPOINTSUPDATE']._serialized_end=19594
  _globals['_MSGTRADINGREWARDPENDINGPOINTSUPDATERESPONSE']._serialized_start=19596
  _globals['_MSGTRADINGREWARDPENDINGPOINTSUPDATERESPONSE']._serialized_end=19641
  _globals['_MSGFEEDISCOUNT']._serialized_start=19644
  _globals['_MSGFEEDISCOUNT']._serialized_end=19805
  _globals['_MSGFEEDISCOUNTRESPONSE']._serialized_start=19807
  _globals['_MSGFEEDISCOUNTRESPONSE']._serialized_end=19831
  _globals['_MSGATOMICMARKETORDERFEEMULTIPLIERSCHEDULE']._serialized_start=19834
  _globals['_MSGATOMICMARKETORDERFEEMULTIPLIERSCHEDULE']._serialized_end=20076
  _globals['_MSGATOMICMARKETORDERFEEMULTIPLIERSCHEDULERESPONSE']._serialized_start=20078
  _globals['_MSGATOMICMARKETORDERFEEMULTIPLIERSCHEDULERESPONSE']._serialized_end=20129
  _globals['_MSG']._serialized_start=20132
  _globals['_MSG']._serialized_end=27109
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict

from grpc.aio import Channel

from pyinjective.core.network import CookieAssistant
from pyinjective.proto.injective.permissions.v1beta1 import (
    query_pb2 as permissions_query_pb,
    query_pb2_grpc as permissions_query_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class ChainGrpcPermissionsApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = permissions_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_module_params(self) -> Dict[str, Any]:
        request = permissions_query_pb.QueryParamsRequest()
        response = await self._execute_call(call=self._stub.Params, request=request)

        return response

    async def fetch_namespace_denoms(self) -> Dict[str, Any]:
        request = permissions_query_pb.QueryNamespaceDenomsRequest()
        response = await self._execute_call(call=self._stub.NamespaceDenoms, request=request)

        return response

    async def fetch_namespaces(self) -> Dict[str, Any]:
        request = permissions_query_pb.QueryNamespacesRequest()
        response = await self._execute_call(call=self._stub.Namespaces, request=request)

        return response

    async def fetch_namespace(self, denom: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryNamespaceRequest(denom=denom)
        response = await self._execute_call(call=self._stub.Namespace, request=request)

        return response

    async def fetch_roles_by_actor(self, denom: str, actor: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryRolesByActorRequest(denom=denom, actor=actor)
        response = await self._execute_call(call=self._stub.RolesByActor, request=request)

        return response

    async def fetch_actors_by_role(self, denom: str, role: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryActorsByRoleRequest(denom=denom, role=role)
        response = await self._execute_call(call=self._stub.ActorsByRole, request=request)

        return response

    async def fetch_role_managers(self, denom: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryRoleManagersRequest(denom=denom)
        response = await self._execute_call(call=self._stub.RoleManagers, request=request)

        return response

    async def fetch_role_manager(self, denom: str, manager: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryRoleManagerRequest(denom=denom, manager=manager)
        response = await self._execute_call(call=self._stub.RoleManager, request=request)

        return response

    async def fetch_policy_statuses(self, denom: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryPolicyStatusesRequest(denom=denom)
        response = await self._execute_call(call=self._stub.PolicyStatuses, request=request)

        return response

    async def fetch_policy_manager_capabilities(self, denom: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryPolicyManagerCapabilitiesRequest(denom=denom)
        response = await self._execute_call(call=self._stub.PolicyManagerCapabilities, request=request)

        return response

    async def fetch_vouchers(self, denom: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryVouchersRequest(denom=denom)
        response = await self._execute_call(call=self._stub.Vouchers, request=request)

        return response

    async def fetch_voucher(self, denom: str, address: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryVoucherRequest(denom=denom, address=address)
        response = await self._execute_call(call=self._stub.Voucher, request=request)

        return response

    async def fetch_permissions_module_state(self) -> Dict[str, Any]:
        request = permissions_query_pb.QueryModuleStateRequest()
        response = await self._execute_call(call=self._stub.PermissionsModuleState, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)
